############################################################
# Analysis of the Kieskompas provincial election data 2023 #
############################################################

# Data retrieved 10 maart 2023 from www.kieskompas.nl as JSON in Firefox (network json copy all)
# The site featured one statement on Distribution Centres: 
# "Distribution centre developments should be banned, even at the cost of jobs"
# In Dutch: "De provincie moet de komst van grote distributiecentra tegenhouden, ook als hierdoor banen verloren gaan"
# Gathered are the political party positions on this statement per province, from strongly agree (+2) to strongly disagree (-2)
# and accompanying argumentation

# Clear R environmenet and load libraries
rm(list=ls())
library(tidyjson) # https://cran.r-project.org/web/packages/tidyjson/vignettes/introduction-to-tidyjson.html
library(tidyverse)

# Define national parties (regional parties are filtered out)
national <- c("50PLUS","Algemene Waterschapspartij","BoerBurgerBeweging","Belang van Nederland","Christen-Democratisch Appel",
                "ChristenUnie","Democraten 66","DENK","Forum voor Democratie", "GroenLinks","JA21",                                   
                 "Partij van de Arbeid","Partij voor de Dieren",                  
                "Partij Voor de Vrijheid", "Socialistische Partij", "Volt",  "Volkspartij voor Vrijheid en Democratie",	
               "Staatkundig Gereformeerde Partij" 
               #parties with only 1 province# ,"Code Oranje","Nederland met een PLAN (S.V.P.)","GrienLinks","Partij van de Arbeid/GroenLinks","Piratenpartij"
               )

# Read, filter, select and join data
distribution <- data.frame()
kieskompas <- function(prov_code,provincie,id_distributiecentra){ #in each province, the DC statement has a different id
    data <- read_json(paste("kieskompas2023/source/",prov_code,".json", sep = ""))
    data |> enter_object() |>  gather_array() |> spread_all() |> enter_object(fk_answers) |>
      gather_array() |> spread_all() |> 
      filter(statement.id == id_distributiecentra) |> 
      select(name,scale = regional_or_national,answer = answer.value,argumentation1 = justification_1.justification, 
      argumentation2 = justification_2.justification) |>
      as_tibble() |> mutate(province = provincie, scale = case_when(
        name %in% national ~ "nationaal",
        TRUE ~ "regionaal")) -> x
    rbind(distribution,x) ->> distribution #add to global var
    #print(x)
}

kieskompas("NH","Noord-Holland",8682)
kieskompas("DR","Drenthe",8713)
kieskompas("GE","Gelderland",8610)
kieskompas("GR","Groningen",8832)
kieskompas("LI","Limburg",8461)
kieskompas("UT","Utrecht",8647)
kieskompas("ZE","Zeeland",8496)
kieskompas("ZH","Zuid-Holland",8806)
## Flevoland: no statement on distribution centres
## Brabant: no statement on distribution centres
## Overijssel: no statement on distribution centres
## Friesland: no statement on distribution centres

write_csv(distribution,"kieskompas2023/processed/Kieskompas_distributiecentra.csv")
## data is cleaned manually from special text characters, to enable data visualization and saved as
## Kieskompas_distributiecentra_clean.csv


# Diagram party positions per province
distribution <- read_csv2("kieskompas2023/processed/Kieskompas_distributiecentra_clean.csv")

location <- c("Zuid-Holland","Noord-Brabant","Gelderland","Limburg") #provinces located in East-Southeast corridor

distribution |> filter(scale == "nationaal") |> 
  mutate(corridor = case_when(
    province %in% location ~ "in corridor",
    TRUE ~ "outside corridor")) |>
  # left_join(rank) |> 
  # arrange(rank) |> mutate(id = paste(name," ",province)) |>
  # mutate(id = factor(id, levels = id)) |> #set order for visualization from positive to negative
  ggplot(aes(y = name, x = answer, color = province, shape = corridor)) +
  geom_jitter(height = 0) + #jitter avoids overlapping symbols
  scale_color_manual(values = c("lightblue1","orange","cadetblue2","gold","cadetblue4",
                                "cadetblue3","cadetblue1","red")) +
  theme_bw(base_size = 15) + 
  theme(plot.title = element_text(size=10),
        #panel.grid.major = element_blank(),
        panel.grid.minor = element_blank()) +
  labs(title = "Distribution centre developments should be banned, even at the cost of jobs",
    x = expression("disagree" %<->% "agree"),
    y = "party")
ggsave(filename = "kieskompas2023/plot/partyscores_NL.png",
       dpi = 300, width = 3000, height = 3000, units = "px")
